"""Example of shallow water wave equation.

Island surrounded by water.
This example investigates onshore 'creep' 

"""


#-------------------------------------------------------------------------------
# Import necessary modules
#-------------------------------------------------------------------------------

# Standard modules
from math import exp

# Application specific imports
from pyvolution.mesh_factory import rectangular
from pyvolution.shallow_water import Domain, Reflective_boundary
from utilities.polygon import Polygon_function, read_polygon


#-------------------------------------------------------------------------------   
# Setup computational domain
#-------------------------------------------------------------------------------

#Create basic mesh
N = 40
points, vertices, boundary = rectangular(N, N, 100, 100)

#Create shallow water domain
domain = Domain(points, vertices, boundary)
domain.smooth = False
domain.set_name('island')
domain.set_default_order(2)


#I tried to introduce this parameter top control the h-limiter,
#but it doesn't remove the 'lapping water'
#NEW (ON): I think it has been fixed (or at least reduced significantly) now
#
# beta_h == 1.0 means that the largest gradients (on h) are allowed
# beta_h == 0.0 means that constant (1st order) gradients are introduced
# on h. This is equivalent to the constant depth used previously.
domain.beta_h = 0.9


#-------------------------------------------------------------------------------
# Setup initial conditions
#-------------------------------------------------------------------------------

def island(x, y):
    z = 0*x
    for i in range(len(x)):
        z[i] = 8*exp( -((x[i]-50)**2 + (y[i]-50)**2)/100 )
    return z

domain.set_quantity('friction', 0.1)
domain.set_quantity('elevation', island)
domain.set_quantity('stage', 1)


#-------------------------------------------------------------------------------
# Setup boundary conditions (all reflective)
#-------------------------------------------------------------------------------

Br = Reflective_boundary(domain)

domain.set_boundary({'left': Br, 'right': Br, 'top': Br, 'bottom': Br})
domain.check_integrity()


#-------------------------------------------------------------------------------
# Evolve system through time
#-------------------------------------------------------------------------------

import time
for t in domain.evolve(yieldstep = 1, finaltime = 100):
    domain.write_time()

print 'Done'
